sleep

Function sleep 

pub(crate) async fn sleep<H>(
    hal: &mut H,
    device_addr: u8,
) -> Result<(), AteccError<H::Error>>
where H: AteccHal,
Put the chip into deep sleep.

Sleep clears volatile state (TempKey, RNG seed) and brings the chip to its lowest power consumption level. The next command requires a fresh wake sequence (which is the same cost as wake-from-idle).

Errors

AteccError::Hal if the I2C write fails.